<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
                xmlns="http://www.w3.org/1999/xhtml">
    
    <xsl:output method="xml"
                doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
                doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"
                encoding="UTF-8"
                indent="yes"
    />

    <xsl:template match="company">
        <html>
            <head>
                <title>Company <xsl:value-of select="name"/></title>
                <meta http-equiv="Content-Style-Type" content="text/css" />
                <link rel="stylesheet" href="company.css" type="text/css" media="screen" />            
            </head>
            <body>
                <h1>Company <xsl:value-of select="name"/></h1>
                <xsl:call-template name="link-list"/>
                <h2>Divisions</h2>
                <xsl:apply-templates select="division"/>
                <h2>Industries</h2>
                <xsl:apply-templates select="industry"/>
            </body>
        </html>
    </xsl:template>

    <xsl:template name="link-list">
        <div class="link-box">
            <ul>
                <lh>Quick links to divisions</lh>
                <xsl:for-each select="division">
                    <li>
                        <a href="#{@did}">
                            <xsl:value-of select="name"/>
                        </a>
                    </li>
                </xsl:for-each>
            </ul>
            <ul>
                <lh>Quick links to industries</lh>
                <xsl:for-each select="industry">
                    <li>
                        <a href="#{@id}">
                            <xsl:value-of select="name"/>
                        </a>
                    </li>
                </xsl:for-each>
            </ul>
        </div>
    </xsl:template>

    <xsl:template match="person">
        <xsl:value-of select="name"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="surname"/> (PID=<xsl:value-of select="@pid"/>)
    </xsl:template>

    <xsl:template match="product">
        <li>
            <xsl:value-of select="name"/>
            &#160;[<a href="#{ancestor::division/@did}">go to division where produced</a>]
        </li>
    </xsl:template>

    <xsl:template match="industry">
        <xsl:variable name="id" select="@id"/>
        <div class="industry">
            <h3>
                <a name="{$id}">
                    <xsl:value-of select="name"/>
                </a>
            </h3>
            <xsl:apply-templates select="description"/>
            <ul>
                <lh>Products:</lh>
                <xsl:apply-templates select="//product[@industry=$id]"/>
            </ul>
        </div>
    </xsl:template>

    <xsl:template match="division">
        <xsl:variable name="did" select="@did"/>
        <div class="division">
            <h3>
                <a name="{$did}">
                    <xsl:value-of select="name"/>
                </a>
            </h3>
            <xsl:apply-templates select="head"/>
            <xsl:apply-templates select="description"/>
            <ul>
                <lh>Products:</lh>
                <xsl:for-each select="products/product">
                    <li>
                        <strong>
                            <xsl:value-of select="name"/>
                        </strong>
                        <xsl:apply-templates select="description"/>
                    </li>
                </xsl:for-each>
            </ul>
        </div>
    </xsl:template>

    <xsl:template match="description">
        <em>
            <xsl:value-of select="."/>
        </em> 
    </xsl:template>
    
    <xsl:template match="head">
        <div>
            <em>Head: </em> 
            <strong>
                <xsl:apply-templates select="person"/>
            </strong>
        </div>
    </xsl:template>
</xsl:stylesheet>
